pub struct ScopedJoinHandle<'scope, T>(/* private fields */);Expand description
An owned permission to join on a scoped thread (block on its termination).
See Scope::spawn for details.
Implementations
Sourceimpl<'scope, T> ScopedJoinHandle<'scope, T>
impl<'scope, T> ScopedJoinHandle<'scope, T>
1.63.0 · Sourcepub fn thread(&self) -> &Thread
pub fn thread(&self) -> &Thread
Extracts a handle to the underlying thread.
Examples
use std::thread;
thread::scope(|s| {
let t = s.spawn(|| {
println!("hello");
});
println!("thread id: {:?}", t.thread().id());
});1.63.0 · Sourcepub fn join(self) -> Result<T, Box<dyn Any + Send>>
pub fn join(self) -> Result<T, Box<dyn Any + Send>>
Waits for the associated thread to finish.
This function will return immediately if the associated thread has already finished.
In terms of atomic memory orderings, the completion of the associated
thread synchronizes with this function returning.
In other words, all operations performed by that thread
happen before
all operations that happen after join returns.
If the associated thread panics, Err is returned with the panic payload.
Examples
use std::thread;
thread::scope(|s| {
let t = s.spawn(|| {
panic!("oh no");
});
assert!(t.join().is_err());
});1.63.0 · Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Checks if the associated thread has finished running its main function.
is_finished supports implementing a non-blocking join operation, by checking
is_finished, and calling join if it returns true. This function does not block. To
block while waiting on the thread to finish, use join.
This might return true for a brief moment after the thread’s main
function has returned, but before the thread itself has stopped running.
However, once this returns true, join can be expected
to return quickly, without blocking for any significant amount of time.